@@ -29,9 +29,9 @@ from cinder.common import constants
 from cinder import context
 from cinder import exception
 from cinder import objects
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit import fake_constants as fake
+from cinder.tests.unit import test
 
 
 CONF = cfg.CONF
@@ -824,34 +824,32 @@ class ServicesTest(test.TestCase):
                           self.controller._get_log, req, self.context,
                           body=body)
 
-    def test_get_log_w_server_filter_same_host(self):
+    @mock.patch('cinder.api.contrib.services.ServiceController._get_log')
+    def test_get_log_w_server_filter(self, get_log_mock):
         server_filter = 'controller-0'
-        CONF.set_override('host', server_filter)
-        body = {'binary': constants.API_BINARY, 'server': server_filter}
+
+        body = {'host': CONF.host, 'server': server_filter}
         req = FakeRequest(version=mv.LOG_LEVEL)
 
-        log_levels = self.controller._get_log(
-            req=req, context=mock.sentinel.context, body=body)
-        log_levels = log_levels['log_levels']
+        log_levels = self.controller._get_log(req, mock.sentinel.context, body)
 
-        self.assertEqual(1, len(log_levels))
-        self.assertEqual('controller-0', log_levels[0]['host'])
-        self.assertEqual('cinder-api', log_levels[0]['binary'])
-        # since there are a lot of log levels, we just check if the key-value
-        # exists for levels
-        self.assertIsNotNone(log_levels[0]['levels'])
+        self.assertEqual(get_log_mock.return_value, log_levels)
+        get_log_mock.assert_called_once_with(req, mock.sentinel.context, body)
+        self.assertNotEqual(log_levels['binary'], constants.API_BINARY)
+        self.assertIsNot(log_levels, constants.API_BINARY)
 
-    def test_get_log_w_server_filter_different_host(self):
-        server_filter = 'controller-0'
-        CONF.set_override('host', 'controller-different-host')
-        body = {'binary': constants.API_BINARY, 'server': server_filter}
+    @mock.patch('cinder.api.contrib.services.ServiceController._get_log')
+    def test_get_log_w_server_equals_to_host(self, get_log_mock):
+        server_filter = 'server-0'
+
+        body = {'host': CONF.host, 'server': server_filter}
         req = FakeRequest(version=mv.LOG_LEVEL)
 
-        log_levels = self.controller._get_log(
-            req=req, context=mock.sentinel.context, body=body)
-        log_levels = log_levels['log_levels']
+        log_levels = self.controller._get_log(req, mock.sentinel.context, body)
 
-        self.assertEqual(0, len(log_levels))
+        self.assertEqual(get_log_mock.return_value, log_levels)
+        self.assertNotEqual(log_levels['binary'], constants.API_BINARY)
+        self.assertIsNot(log_levels, constants.API_BINARY)
 
     @ddt.data(None, '', '*')
     @mock.patch('cinder.objects.ServiceList.get_all')
