@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Tests for group code.
-"""
+"""Tests for group code."""
+
+from unittest import mock
 
 import ddt
-import mock
 from six.moves import http_client
 import webob
 
@@ -30,10 +29,10 @@ from cinder import exception
 import cinder.group
 from cinder import objects
 from cinder.objects import fields
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit.api.v3 import fakes as v3_fakes
 from cinder.tests.unit import fake_constants as fake
+from cinder.tests.unit import test
 from cinder.tests.unit import utils
 from cinder.volume import api as volume_api
 
