@@ -10,8 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import datetime
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 
@@ -23,9 +23,9 @@ from cinder import context
 from cinder import exception
 from cinder.message import api as message_api
 from cinder.message import message_field
-from cinder import test
 from cinder.tests.unit.api import fakes
 import cinder.tests.unit.fake_constants as fake_constants
+from cinder.tests.unit import test
 from cinder.tests.unit import utils
 
 CONF = cfg.CONF
