@@ -65,13 +65,6 @@ RBD_OPTS = [
     cfg.StrOpt('rbd_ceph_conf',
                default='',  # default determined by librados
                help='Path to the ceph configuration file'),
-    cfg.StrOpt('rbd_keyring_conf',
-               deprecated_for_removal=True,
-               deprecated_reason='Use of this option exposes a security '
-                                 'vulnerability.  See OSSN-0085 for details.',
-               deprecated_since='Ussuri',
-               default='',
-               help='Path to the ceph keyring file'),
     cfg.BoolOpt('rbd_flatten_volume_from_snapshot',
                 default=False,
                 help='Flatten volumes created from snapshots to remove '
@@ -83,9 +76,7 @@ RBD_OPTS = [
                default=5,
                help='Maximum number of nested volume clones that are '
                     'taken before a flatten occurs. Set to 0 to disable '
-                    'cloning. Note: lowering this value will not affect '
-                    'existing volumes whose clone depth exceeds the new '
-                    'value.'),
+                    'cloning.'),
     cfg.IntOpt('rbd_store_chunk_size', default=4,
                help='Volumes will be chunked into objects of this size '
                     '(in megabytes).'),
@@ -255,7 +246,6 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         self._is_replication_enabled = False
         self._replication_targets = []
         self._target_names = []
-        self._clone_v2_api_checked = False
 
         if self.rbd is not None:
             self.RBD_FEATURE_LAYERING = self.rbd.RBD_FEATURE_LAYERING
@@ -271,6 +261,30 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             self.RBD_FEATURE_OBJECT_MAP |
             self.RBD_FEATURE_EXCLUSIVE_LOCK)
 
+        self._set_keyring_attributes()
+
+    def _set_keyring_attributes(self):
+        # The rbd_keyring_conf option is not available for OpenStack usage
+        # for security reasons (OSSN-0085) and in OpenStack we use
+        # rbd_secret_uuid or make sure that the keyring files are present on
+        # the hosts (where os-brick will look for them).
+        # For cinderlib usage this option is necessary (no security issue, as
+        # in those cases the contents of the connection are not available to
+        # users). By using getattr Oslo-conf won't read the option from the
+        # file even if it's there (because we have removed the conf option
+        # definition), but cinderlib will find it because it sets the option
+        # directly as an attribute.
+        self.keyring_file = getattr(self.configuration, 'rbd_keyring_conf',
+                                    None)
+
+        self.keyring_data = None
+        try:
+            if self.keyring_file and os.path.isfile(self.keyring_file):
+                with open(self.keyring_file, 'r') as k_file:
+                    self.keyring_data = k_file.read()
+        except IOError:
+            LOG.debug('Cannot read RBD keyring file: %s.', self.keyring_file)
+
     @classmethod
     def get_driver_options(cls):
         additional_opts = cls._get_oslo_driver_opts(
@@ -278,22 +292,6 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             'max_over_subscription_ratio', 'volume_dd_blocksize')
         return RBD_OPTS + additional_opts
 
-    def _show_msg_check_clone_v2_api(self, volume_name):
-        if not self._clone_v2_api_checked:
-            self._clone_v2_api_checked = True
-            with RBDVolumeProxy(self, volume_name, read_only=True) as volume:
-                try:
-                    if (volume.volume.op_features() &
-                            self.rbd.RBD_OPERATION_FEATURE_CLONE_PARENT):
-                        LOG.info('Using v2 Clone API')
-                        return
-                except AttributeError:
-                    pass
-                LOG.warning('Not using v2 clone API, please upgrade to'
-                            ' mimic+ and set the OSD minimum client'
-                            ' compat version to mimic for better'
-                            ' performance, fewer deletion issues')
-
     def _get_target_config(self, target_id):
         """Get a replication target from known replication targets."""
         for target in self._replication_targets:
@@ -414,6 +412,14 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
                 LOG.error(msg)
                 raise exception.VolumeBackendAPIException(data=msg)
 
+        # If the keyring is defined (cinderlib usage), then the contents are
+        # necessary.
+        if self.keyring_file and not self.keyring_data:
+            msg = _('No keyring data found')
+            LOG.error(msg)
+            raise exception.InvalidConfigurationValue(
+                option='rbd_keyring_conf', value=self.keyring_file)
+
         self._start_periodic_tasks()
 
     def RBDProxy(self):
@@ -550,14 +556,14 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
 
         with RADOSClient(self) as client:
             ret, df_outbuf, __ = client.cluster.mon_command(
-                '{"prefix":"df", "format":"json"}', b'')
+                '{"prefix":"df", "format":"json"}', '')
             if ret:
                 LOG.warning('Unable to get rados pool stats.')
                 return 'unknown', 'unknown'
 
             ret, quota_outbuf, __ = client.cluster.mon_command(
                 '{"prefix":"osd pool get-quota", "pool": "%s",'
-                ' "format":"json"}' % pool_name, b'')
+                ' "format":"json"}' % pool_name, '')
             if ret:
                 LOG.warning('Unable to get rados pool quotas.')
                 return 'unknown', 'unknown'
@@ -638,20 +644,9 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             LOG.exception('error refreshing volume stats')
         self._stats = stats
 
-    def get_volume_stats(self, refresh=False):
-        """Return the current state of the volume service.
-
-        If 'refresh' is True, run the update first.
-        """
-        if refresh:
-            self._update_volume_stats()
-        return self._stats
-
     def _get_clone_depth(self, client, volume_name, depth=0):
         """Returns the number of ancestral clones of the given volume."""
-        parent_volume = self.rbd.Image(client.ioctx,
-                                       volume_name,
-                                       read_only=True)
+        parent_volume = self.rbd.Image(client.ioctx, volume_name)
         try:
             _pool, parent, _snap = self._get_clone_info(parent_volume,
                                                         volume_name)
@@ -661,6 +656,12 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         if not parent:
             return depth
 
+        # If clone depth was reached, flatten should have occurred so if it has
+        # been exceeded then something has gone wrong.
+        if depth > self.configuration.rbd_max_clone_depth:
+            raise Exception(_("clone depth exceeds limit of %s") %
+                            (self.configuration.rbd_max_clone_depth))
+
         return self._get_clone_depth(client, parent, depth + 1)
 
     def _extend_if_required(self, volume, src_vref):
@@ -730,18 +731,16 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             depth = self._get_clone_depth(client, src_name)
             # If dest volume is a clone and rbd_max_clone_depth reached,
             # flatten the dest after cloning. Zero rbd_max_clone_depth means
-            # volumes are always flattened.
+            # infinite is allowed.
             if depth >= self.configuration.rbd_max_clone_depth:
                 LOG.info("maximum clone depth (%d) has been reached - "
                          "flattening dest volume",
                          self.configuration.rbd_max_clone_depth)
-
-                # Flatten destination volume
+                dest_volume = self.rbd.Image(client.ioctx, dest_name)
                 try:
-                    with RBDVolumeProxy(self, dest_name, client=client,
-                                        ioctx=client.ioctx) as dest_volume:
-                        LOG.debug("flattening dest volume %s", dest_name)
-                        dest_volume.flatten()
+                    # Flatten destination volume
+                    LOG.debug("flattening dest volume %s", dest_name)
+                    dest_volume.flatten()
                 except Exception as e:
                     msg = (_("Failed to flatten volume %(volume)s with "
                              "error: %(error)s.") %
@@ -750,6 +749,8 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
                     LOG.exception(msg)
                     src_volume.close()
                     raise exception.VolumeBackendAPIException(data=msg)
+                finally:
+                    dest_volume.close()
 
                 try:
                     # remove temporary snap
@@ -987,35 +988,16 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         with RBDVolumeProxy(self, volume_name, pool) as vol:
             vol.flatten()
 
-    def _get_stripe_unit(self, ioctx, volume_name):
-        """Return the correct stripe unit for a cloned volume.
-
-        A cloned volume must be created with a stripe unit at least as large
-        as the source volume.  We compute the desired stripe width from
-        rbd_store_chunk_size and compare that to the incoming source volume's
-        stripe width, selecting the larger to avoid error.
-        """
-        default_stripe_unit = \
-            self.configuration.rbd_store_chunk_size * units.Mi
-
-        image = self.rbd.Image(ioctx, volume_name, read_only=True)
-        try:
-            image_stripe_unit = image.stripe_unit()
-        finally:
-            image.close()
-
-        return max(image_stripe_unit, default_stripe_unit)
-
     def _clone(self, volume, src_pool, src_image, src_snap):
         LOG.debug('cloning %(pool)s/%(img)s@%(snap)s to %(dst)s',
                   dict(pool=src_pool, img=src_image, snap=src_snap,
                        dst=volume.name))
 
+        chunk_size = self.configuration.rbd_store_chunk_size * units.Mi
+        order = int(math.log(chunk_size, 2))
         vol_name = utils.convert_str(volume.name)
 
         with RADOSClient(self, src_pool) as src_client:
-            stripe_unit = self._get_stripe_unit(src_client.ioctx, src_image)
-            order = int(math.log(stripe_unit, 2))
             with RADOSClient(self) as dest_client:
                 self.RBDProxy().clone(src_client.ioctx,
                                       utils.convert_str(src_image),
@@ -1024,6 +1006,7 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
                                       vol_name,
                                       features=src_client.features,
                                       order=order)
+
             try:
                 volume_update = self._setup_volume(volume)
             except Exception:
@@ -1049,8 +1032,6 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             self._flatten(self.configuration.rbd_pool, volume.name)
         if int(volume.size):
             self._resize(volume)
-
-        self._show_msg_check_clone_v2_api(snapshot.volume_name)
         return volume_update
 
     def _delete_backup_snaps(self, rbd_image):
@@ -1455,20 +1436,6 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         """Removes an export for a logical volume."""
         pass
 
-    def _get_keyring_contents(self):
-        # NOTE(danpawlik) If keyring is not provided in Cinder configuration,
-        # os-brick library will take keyring from default path.
-        keyring_file = self.configuration.rbd_keyring_conf
-        keyring_data = None
-        try:
-            if os.path.isfile(keyring_file):
-                with open(keyring_file, 'r') as k_file:
-                    keyring_data = k_file.read()
-        except IOError:
-            LOG.debug('Cannot read RBD keyring file: %s.', keyring_file)
-
-        return keyring_data
-
     def initialize_connection(self, volume, connector):
         hosts, ports = self._get_mon_addrs()
         name, conf, user, secret_uuid = self._get_config_tuple()
@@ -1486,9 +1453,10 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
                 'secret_uuid': secret_uuid,
                 'volume_id': volume.id,
                 "discard": True,
-                'keyring': self._get_keyring_contents(),
             }
         }
+        if self.keyring_data:
+            data['data']['keyring'] = self.keyring_data
         LOG.debug('connection data: %s', data)
         return data
 
@@ -1640,13 +1608,7 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             if encrypted:
                 self._encrypt_image(context, volume, tmp_dir, tmp.name)
 
-            @utils.retry(exception.VolumeIsBusy,
-                         self.configuration.rados_connection_interval,
-                         self.configuration.rados_connection_retries)
-            def _delete_volume(volume):
-                self.delete_volume(volume)
-
-            _delete_volume(volume)
+            self.delete_volume(volume)
 
             chunk_size = self.configuration.rbd_store_chunk_size * units.Mi
             order = int(math.log(chunk_size, 2))
@@ -1740,9 +1702,7 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         with RADOSClient(self) as client:
             # Raise an exception if we didn't find a suitable rbd image.
             try:
-                rbd_image = self.rbd.Image(client.ioctx,
-                                           rbd_name,
-                                           read_only=True)
+                rbd_image = self.rbd.Image(client.ioctx, rbd_name)
             except self.rbd.ImageNotFound:
                 kwargs = {'existing_ref': rbd_name,
                           'reason': 'Specified rbd image does not exist.'}
@@ -1969,8 +1929,7 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             # Raise an exception if we didn't find a suitable rbd image.
             try:
                 rbd_snapshot = self.rbd.Image(client.ioctx, volume_name,
-                                              snapshot=snapshot_name,
-                                              read_only=True)
+                                              snapshot=snapshot_name)
             except self.rbd.ImageNotFound:
                 kwargs = {'existing_ref': snapshot_name,
                           'reason': 'Specified snapshot does not exist.'}
