@@ -98,7 +98,6 @@ class OnFailureRescheduleTask(flow_utils.CinderTask):
             # they fail, rescheduling will likely attempt to create the volume
             # on another machine when it still exists locally.
             exception.MetadataCopyFailure,
-            exception.MetadataCreateFailure,
             exception.MetadataUpdateFailure,
             # The volume/snapshot has been removed from the database, that
             # can not be fixed by rescheduling.
@@ -498,7 +497,7 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
         new_key_id = volume_utils.create_encryption_key(context,
                                                         keymgr,
                                                         volume.volume_type_id)
-        new_key = keymgr.get(context, new_key_id)
+        new_key = keymgr.get(context, encryption['encryption_key_id'])
         new_pass = binascii.hexlify(new_key.get_encoded()).decode('utf-8')
 
         return (source_pass, new_pass, new_key_id)
